@@ -17,14 +17,14 @@ from simpleconf import ProfileConfig
 from slugify import slugify  # type: ignore
 from varname import varname, VarnameException
 
-from .defaults import CONFIG, CONFIG_FILES, CONSOLE_WIDTH
+from .defaults import CONFIG, CONFIG_FILES, CONSOLE_WIDTH, CONSOLE_WIDTH_SHIFT
 from .exceptions import ProcDependencyError, PipenSetDataError
 from .pluginmgr import plugin
 from .proc import Proc
 from .progressbar import PipelinePBar
 from .utils import (
     copy_dict,
-    get_console_width,
+    get_logcontent_width,
     get_plugin_context,
     log_rich_renderable,
     logger,
@@ -338,7 +338,9 @@ class Pipen:
             Panel(
                 Group(*items),
                 title=self.name.upper(),
-                width=min(CONSOLE_WIDTH, get_console_width()),
+                width=get_logcontent_width(
+                    max_width=CONSOLE_WIDTH - CONSOLE_WIDTH_SHIFT
+                ),
                 box=box.Box(
                     "╭═┬╮\n"
                     "║ ║║\n"
@@ -373,7 +375,8 @@ class Pipen:
             ignore_nonexist=True,
         )
         self.config = ProfileConfig.use_profile(
-            config, self.profile, copy=True)
+            config, self.profile, copy=True
+        )
 
         # configs from files and CONFIG are loaded
         # allow plugins to change the default configs
